from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ("game", "0029_level_pythonviewenabled"),
        ("game", "0029_disable_route_scores"),
    ]

    operations = []
